@@ -11,8 +11,8 @@ from raylab.policy.modules.critic import QValueEnsemble
 from raylab.policy.modules.critic import VValue
 from raylab.policy.modules.model import SME
 from raylab.policy.modules.model import StochasticModel
-from raylab.utils.annotations import StatDict
-from raylab.utils.annotations import TensorDict
+from raylab.utils.types import StatDict
+from raylab.utils.types import TensorDict
 
 from .abstract import Loss
 from .mixins import EnvFunctionsMixin
